# Cn-打造全中文编程
- [简介](#简介)
- [下载](#下载)
- [使用](#使用)
    - [打印](#打印)
    - [引用](#引用)
    - [变量](#变量)
    - [随机数](#随机数)
    - [网络通信](#网络通信)
    - [询问](#询问)
    - [终端控制](#终端控制)


## 简介

Cn是由双叶团队开发的一种中文编程语言

官网:[heikeling.github.io](https://heikeling.github.io)

开发人员:Rainwangpupil, Heikeling, Code X

## 下载

终端输入一下命令：
`pip3 install cnforpy`

## 使用

终端输入以下命令：
`cnforpy`

此时你会看到一个窗口，即为cn的编程页面

### 打印
类似于Python的`print()`

语法：

打印：你好CN!

输出:
`你好CN!`

### 引用

类似于Python的`import`

语法：

引用：随机

### 变量

CN的变量语法：

```
新建变量：
设置变量名：我最喜欢的编程语言
设置变量值：CN
```

等同于以下Python代码

```python
我最喜欢的编程语言 = "CN"
```

### 随机数

随机数需要引用`随机模块`

CN随机数语法:

```
引用：随机
随机数一：52
随机数二：78
```

另外，你还可以打印随机数

```
引用：随机
随机数一：52
随机数二：78
打印随机数
```

终端输出：
`62`

### 网络通信
网络通信套用了Python的`requests`模块，

语法：

```
引用：请求
请求网站源码：https://baidu.com
请求网页状态：https://heikeling.github.io
```

### 询问

询问后，会弹出一个窗口，输入内容，并存储在一个变量中

语法：

```
询问：你最喜欢的编程语言是什么？
```

你还可以获取他人的答复

```
打印：获取答复
```

终端输出：

```
（询问你最喜欢的编程语言）
（用户写了CN)
CN
```

### 终端控制

这个功能使用了Python的`os.system()`函数

语法：

```
引用：终端
终端输入：echo CN是我最喜欢的语言
```

输出:
`CN是我最喜欢的语言`

关于CN的介绍就到这里，如果想了解更多，可以到CN语言的官网(https://heikeling.github.io)查看，我就介绍到这里，希望您快乐的使用CN!